@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 # package exports and version
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 our @EXPORT_OK = ();
 
 # module imports
@@ -85,6 +85,13 @@ sub menu_plugins {
 		sub { $self->_show_quick_outline_access_dialog(); },
 	);
 
+	# Shows the "Quick Module Access" dialog
+	Wx::Event::EVT_MENU(
+		$main_window,
+		$self->{menu}->Append( -1, _T("Quick Module Access\tCtrl-5"), ),
+		sub { $self->_show_quick_module_access_dialog(); },
+	);
+
 	#---------
 	$self->{menu}->AppendSeparator;
 
@@ -158,6 +165,20 @@ sub _show_quick_outline_access_dialog {
 	return;
 }
 
+#
+# Opens the "Quick Module Access" dialog
+#
+sub _show_quick_module_access_dialog {
+	my $self = shift;
+
+	#Create and show the dialog
+	require Padre::Plugin::Ecliptic::QuickModuleAccessDialog;
+	my $dialog  = Padre::Plugin::Ecliptic::QuickModuleAccessDialog->new($self);
+	$dialog->ShowModal();
+
+	return;
+}
+
 1;
 
 __END__
