@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 # package exports and version
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 our @EXPORT_OK = ();
 
 # module imports
@@ -202,7 +202,7 @@ sub _setup_events {
 		if($num_selected > 1) {
 			$self->_status_text->SetLabel(
 				"" . scalar @matches . _T(" items selected"));
-		} else {
+		} elsif($num_selected == 1) {
 			$self->_status_text->SetLabel(
 				$self->_matches_list->GetString($matches[0]));
 		}
